/***************************************************
Copyright (c) 2019 Luis Llamas
(www.luisllamas.es)
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License
 ****************************************************/

/*  Adapted for ESP32 usage by Volker Frauenstein 
 *  Date: 05/01/2021
 *  Version: 1.0
 */

#include "BTS7960ESP32.h"

BTS7960ESP32::BTS7960ESP32(uint8_t L_EN, uint8_t R_EN, uint8_t L_PWM, uint8_t R_PWM, uint8_t freq, uint8_t L_pwmChannel, uint8_t R_pwmChannel){
	_R_PWM = R_PWM;
	_L_PWM = L_PWM;
	_L_EN = L_EN;
	_R_EN = R_EN;
	_R_pwmChannel = R_pwmChannel;
	_L_pwmChannel = L_pwmChannel;
	_freq = freq;

	pinMode(_R_PWM, OUTPUT);
	pinMode(_L_PWM, OUTPUT);
	pinMode(_L_EN, OUTPUT);
	pinMode(_R_EN, OUTPUT);

    ledcSetup( _R_pwmChannel, _freq, 8);
    ledcSetup( _L_pwmChannel, _freq, 8);

    ledcAttachPin(_R_PWM, _R_pwmChannel);
    ledcAttachPin(_L_PWM, _L_pwmChannel);
}

void BTS7960ESP32::TurnRight(uint8_t pwm){
     ledcWrite(_R_pwmChannel, 0);
	   delayMicroseconds(100);
     ledcWrite(_R_pwmChannel, pwm);
}

void BTS7960ESP32::TurnLeft(uint8_t pwm){
     ledcWrite(_R_pwmChannel, 0);
	   delayMicroseconds(100);
     ledcWrite(_L_pwmChannel, pwm);
}

void BTS7960ESP32::Enable(){
	digitalWrite(_L_EN, HIGH);
  digitalWrite(_R_EN, HIGH);
  ledcWrite(_L_pwmChannel, 0);
  ledcWrite(_R_pwmChannel, 0);
}

void BTS7960ESP32::Disable(){
	digitalWrite(_L_EN, LOW);
  digitalWrite(_R_EN, LOW);
  ledcWrite(_L_pwmChannel, 0);
  ledcWrite(_R_pwmChannel, 0);
}

void BTS7960ESP32::Stop(){
  ledcWrite(_L_pwmChannel, 0);
  ledcWrite(_R_pwmChannel, 0);
}
